==> ejc-labor-impl-3.0.0-20221116.095757-17-sources.jar: com/ejianc/business/labor/bean/WorkerEnterEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 劳务进场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_worker_enter")
public class WorkerEnterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex")
    private Integer sex; // 1-男，2-女
    @TableField(value="birth_date")
    private Date birthDate; // 出生日期
    @TableField(value="user_age")
    private Integer userAge; // 年龄
    @TableField(value="nation")
    private String nation; // 民族
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="team_id")
    private String teamId; // 劳务班组
    @TableField(value="team_name")
    private String teamName; // 劳务班组名称
    @TableField(value="work_type")
    private Long workType; // 工种
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="wages_type_name")
    private String wagesTypeName; // 工资类型名称
    @TableField(value="wage")
    private BigDecimal wage; // 工价
    @TableField(value="province")
    private String province; // 省
    @TableField(value="city")
    private String city; // 市
    @TableField(value="area")
    private String area; // 省市
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源：1-自制 项目班组 2、公司花名册 3、邀请
    @TableField(value="source_flag_name")
    private String sourceFlagName; // 来源名称
    @TableField(value="id_card_photo_flag")
    private Integer idCardPhotoFlag; // 身份证照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="face_photo_flag")
    private Integer facePhotoFlag; // 人脸采集状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="work_state")
    private Integer workState; // 用工状态：0未入场，1已入场
    @TableField(value="enabled")
    private Integer enabled; // 1:启用/0:停用
    @TableField(value="project_id")
    private Long projectId; // 所属项目
    @TableField(value="project_name")
    private String projectName; // 所属项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="sub_contract_id")
    private Long subContractId; // 分包合同id
    @TableField(value="sub_contract_name")
    private String subContractName; // 分包合同
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商ID
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="enter_date")
    private Date enterDate; // 进场日期
    @TableField(value="manage_date")
    private Date manageDate; // 办理日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "id_card_name")
    private String idCardName; // 身份证照片识别的姓名
    @TableField(value = "id_card_no")
    private String idCardNo; // 身份证照片识别的身份证号
    @TableField(value = "id_card_sex")
    private String idCardSex; // 身份证照片识别的性别，1-男，2-女
    @TableField(value = "id_card_birth_date")
    private String idCardBirthDate; // 身份证照片识别的出生年月
    @TableField(value = "id_card_nation")
    private String idCardNation; // 身份证照片识别的民族
    @TableField(value = "id_card_start_date")
    private String idCardStartDate; // 身份证照片识别的起始有效期
    @TableField(value = "id_card_end_date")
    private String idCardEndDate; // 身份证照片识别的截止有效期
    @TableField(value = "id_card_issue")
    private String idCardIssue; // 身份证照片识别的签发机关
    /**
     * 单据编码
     */
    @TableField("bill_code")
    private String billCode;

    /**
     * 单据状态（审批必须字段）
     */
    @TableField("bill_state")
    private Integer billState;
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }
    public Integer getUserAge() {
        return userAge;
    }

    public void setUserAge(Integer userAge) {
        this.userAge = userAge;
    }
    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public Long getWorkType() {
        return workType;
    }

    public void setWorkType(Long workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public String getWagesTypeName() {
        return wagesTypeName;
    }

    public void setWagesTypeName(String wagesTypeName) {
        this.wagesTypeName = wagesTypeName;
    }
    public BigDecimal getWage() {
        return wage;
    }

    public void setWage(BigDecimal wage) {
        this.wage = wage;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public String getSourceFlagName() {
        return sourceFlagName;
    }

    public void setSourceFlagName(String sourceFlagName) {
        this.sourceFlagName = sourceFlagName;
    }
    public Integer getIdCardPhotoFlag() {
        return idCardPhotoFlag;
    }

    public void setIdCardPhotoFlag(Integer idCardPhotoFlag) {
        this.idCardPhotoFlag = idCardPhotoFlag;
    }
    public Integer getFacePhotoFlag() {
        return facePhotoFlag;
    }

    public void setFacePhotoFlag(Integer facePhotoFlag) {
        this.facePhotoFlag = facePhotoFlag;
    }
    public Integer getWorkState() {
        return workState;
    }

    public void setWorkState(Integer workState) {
        this.workState = workState;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getSubContractId() {
        return subContractId;
    }

    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    public String getSubContractName() {
        return subContractName;
    }

    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public Date getManageDate() {
        return manageDate;
    }

    public void setManageDate(Date manageDate) {
        this.manageDate = manageDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getIdCardName() {
        return idCardName;
    }

    public void setIdCardName(String idCardName) {
        this.idCardName = idCardName;
    }
    public String getIdCardNo() {
        return idCardNo;
    }

    public void setIdCardNo(String idCardNo) {
        this.idCardNo = idCardNo;
    }

    public String getIdCardSex() {
        return idCardSex;
    }

    public void setIdCardSex(String idCardSex) {
        this.idCardSex = idCardSex;
    }

    public String getIdCardBirthDate() {
        return idCardBirthDate;
    }

    public void setIdCardBirthDate(String idCardBirthDate) {
        this.idCardBirthDate = idCardBirthDate;
    }

    public String getIdCardNation() {
        return idCardNation;
    }

    public void setIdCardNation(String idCardNation) {
        this.idCardNation = idCardNation;
    }

    public String getIdCardStartDate() {
        return idCardStartDate;
    }

    public void setIdCardStartDate(String idCardStartDate) {
        this.idCardStartDate = idCardStartDate;
    }

    public String getIdCardEndDate() {
        return idCardEndDate;
    }

    public void setIdCardEndDate(String idCardEndDate) {
        this.idCardEndDate = idCardEndDate;
    }

    public String getIdCardIssue() {
        return idCardIssue;
    }

    public void setIdCardIssue(String idCardIssue) {
        this.idCardIssue = idCardIssue;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}

==> ejc-labor-impl-3.0.0-20221117.144517-23-sources.jar: com/ejianc/business/labor/bean/WorkerEnterEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 劳务进场单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_worker_enter")
public class WorkerEnterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex")
    private Integer sex; // 1-男，2-女
    @TableField(value="birth_date")
    private Date birthDate; // 出生日期
    @TableField(value="user_age")
    private Integer userAge; // 年龄
    @TableField(value="nation")
    private String nation; // 民族
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="team_id")
    private String teamId; // 劳务班组
    @TableField(value="team_name")
    private String teamName; // 劳务班组名称
    @TableField(value="work_type")
    private Long workType; // 工种
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="wages_type_name")
    private String wagesTypeName; // 工资类型名称
    @TableField(value="wage")
    private BigDecimal wage; // 工价
    @TableField(value="province")
    private String province; // 省
    @TableField(value="city")
    private String city; // 市
    @TableField(value="area")
    private String area; // 省市
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源：1-自制 项目班组 2、公司花名册 3、邀请
    @TableField(value="source_flag_name")
    private String sourceFlagName; // 来源名称
    @TableField(value="id_card_photo_flag")
    private Integer idCardPhotoFlag; // 身份证照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="face_photo_flag")
    private Integer facePhotoFlag; // 人脸采集状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="work_state")
    private Integer workState; // 用工状态：0未入场，1已入场
    @TableField(value="enabled")
    private Integer enabled; // 1:启用/0:停用
    @TableField(value="project_id")
    private Long projectId; // 所属项目
    @TableField(value="project_name")
    private String projectName; // 所属项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="sub_contract_id")
    private Long subContractId; // 分包合同id
    @TableField(value="sub_contract_name")
    private String subContractName; // 分包合同
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商ID
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="enter_date")
    private Date enterDate; // 进场日期
    @TableField(value="manage_date")
    private Date manageDate; // 办理日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "id_card_name")
    private String idCardName; // 身份证照片识别的姓名
    @TableField(value = "id_card_no")
    private String idCardNo; // 身份证照片识别的身份证号
    @TableField(value = "id_card_sex")
    private String idCardSex; // 身份证照片识别的性别，1-男，2-女
    @TableField(value = "id_card_birth_date")
    private String idCardBirthDate; // 身份证照片识别的出生年月
    @TableField(value = "id_card_nation")
    private String idCardNation; // 身份证照片识别的民族
    @TableField(value = "id_card_start_date")
    private String idCardStartDate; // 身份证照片识别的起始有效期
    @TableField(value = "id_card_end_date")
    private String idCardEndDate; // 身份证照片识别的截止有效期
    @TableField(value = "id_card_issue")
    private String idCardIssue; // 身份证照片识别的签发机关
    /**
     * 单据编码
     */
    @TableField("bill_code")
    private String billCode;

    /**
     * 单据状态（审批必须字段）
     */
    @TableField("bill_state")
    private Integer billState;

    @TableField(value="id_card_front_photo_flag")
    private Integer idCardFrontPhotoFlag; // 身份证正面照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="id_card_front_photo_exceptional")
    private String idCardFrontPhotoExceptional; // 身份证正面异常信息
    @TableField(value="id_card_back_photo_flag")
    private Integer idCardBackPhotoFlag; // 身份证反面照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="id_card_back_photo_exceptional")
    private String idCardBackPhotoExceptional; // 身份证反面异常信息
    @TableField(value="face_photo_exceptional")
    private String facePhotoExceptional; // 人脸采集异常信息

    public Integer getIdCardFrontPhotoFlag() {
        return idCardFrontPhotoFlag;
    }

    public void setIdCardFrontPhotoFlag(Integer idCardFrontPhotoFlag) {
        this.idCardFrontPhotoFlag = idCardFrontPhotoFlag;
    }

    public String getIdCardFrontPhotoExceptional() {
        return idCardFrontPhotoExceptional;
    }

    public void setIdCardFrontPhotoExceptional(String idCardFrontPhotoExceptional) {
        this.idCardFrontPhotoExceptional = idCardFrontPhotoExceptional;
    }

    public Integer getIdCardBackPhotoFlag() {
        return idCardBackPhotoFlag;
    }

    public void setIdCardBackPhotoFlag(Integer idCardBackPhotoFlag) {
        this.idCardBackPhotoFlag = idCardBackPhotoFlag;
    }

    public String getIdCardBackPhotoExceptional() {
        return idCardBackPhotoExceptional;
    }

    public void setIdCardBackPhotoExceptional(String idCardBackPhotoExceptional) {
        this.idCardBackPhotoExceptional = idCardBackPhotoExceptional;
    }

    public String getFacePhotoExceptional() {
        return facePhotoExceptional;
    }

    public void setFacePhotoExceptional(String facePhotoExceptional) {
        this.facePhotoExceptional = facePhotoExceptional;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }
    public Integer getUserAge() {
        return userAge;
    }

    public void setUserAge(Integer userAge) {
        this.userAge = userAge;
    }
    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public Long getWorkType() {
        return workType;
    }

    public void setWorkType(Long workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public String getWagesTypeName() {
        return wagesTypeName;
    }

    public void setWagesTypeName(String wagesTypeName) {
        this.wagesTypeName = wagesTypeName;
    }
    public BigDecimal getWage() {
        return wage;
    }

    public void setWage(BigDecimal wage) {
        this.wage = wage;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public String getSourceFlagName() {
        return sourceFlagName;
    }

    public void setSourceFlagName(String sourceFlagName) {
        this.sourceFlagName = sourceFlagName;
    }
    public Integer getIdCardPhotoFlag() {
        return idCardPhotoFlag;
    }

    public void setIdCardPhotoFlag(Integer idCardPhotoFlag) {
        this.idCardPhotoFlag = idCardPhotoFlag;
    }
    public Integer getFacePhotoFlag() {
        return facePhotoFlag;
    }

    public void setFacePhotoFlag(Integer facePhotoFlag) {
        this.facePhotoFlag = facePhotoFlag;
    }
    public Integer getWorkState() {
        return workState;
    }

    public void setWorkState(Integer workState) {
        this.workState = workState;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getSubContractId() {
        return subContractId;
    }

    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    public String getSubContractName() {
        return subContractName;
    }

    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public Date getManageDate() {
        return manageDate;
    }

    public void setManageDate(Date manageDate) {
        this.manageDate = manageDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getIdCardName() {
        return idCardName;
    }

    public void setIdCardName(String idCardName) {
        this.idCardName = idCardName;
    }
    public String getIdCardNo() {
        return idCardNo;
    }

    public void setIdCardNo(String idCardNo) {
        this.idCardNo = idCardNo;
    }

    public String getIdCardSex() {
        return idCardSex;
    }

    public void setIdCardSex(String idCardSex) {
        this.idCardSex = idCardSex;
    }

    public String getIdCardBirthDate() {
        return idCardBirthDate;
    }

    public void setIdCardBirthDate(String idCardBirthDate) {
        this.idCardBirthDate = idCardBirthDate;
    }

    public String getIdCardNation() {
        return idCardNation;
    }

    public void setIdCardNation(String idCardNation) {
        this.idCardNation = idCardNation;
    }

    public String getIdCardStartDate() {
        return idCardStartDate;
    }

    public void setIdCardStartDate(String idCardStartDate) {
        this.idCardStartDate = idCardStartDate;
    }

    public String getIdCardEndDate() {
        return idCardEndDate;
    }

    public void setIdCardEndDate(String idCardEndDate) {
        this.idCardEndDate = idCardEndDate;
    }

    public String getIdCardIssue() {
        return idCardIssue;
    }

    public void setIdCardIssue(String idCardIssue) {
        this.idCardIssue = idCardIssue;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}
